@@ -1,5 +1,5 @@
 package Consul::API::Session;
-$Consul::API::Session::VERSION = '0.026';
+$Consul::API::Session::VERSION = '0.027';
 use namespace::autoclean;
 
 use Moo::Role;
@@ -73,7 +73,7 @@ sub renew {
 }
 
 package Consul::API::Session::Session;
-$Consul::API::Session::Session::VERSION = '0.026';
+$Consul::API::Session::Session::VERSION = '0.027';
 use Moo;
 use Types::Standard qw(Str Enum ArrayRef Num Int);
 
@@ -82,7 +82,7 @@ has name         => ( is => 'ro', isa => Str,                      init_arg => '
 has behavior     => ( is => 'ro', isa => Enum[qw(release delete)], init_arg => 'Behavior',    required => 1 );
 has ttl          => ( is => 'ro', isa => Str,                      init_arg => 'TTL',         required => 1 );
 has node         => ( is => 'ro', isa => Str,                      init_arg => 'Node',        required => 1 );
-has checks       => ( is => 'ro', isa => ArrayRef[Str],            init_arg => 'Checks',      required => 1 );
+has checks       => ( is => 'ro', isa => ArrayRef[Str],            init_arg => 'Checks',                    );
 has lock_delay   => ( is => 'ro', isa => Num,                      init_arg => 'LockDelay',   required => 1 );
 has create_index => ( is => 'ro', isa => Int,                      init_arg => 'CreateIndex', required => 1 );
 
